.. raw:: html

    <p align="center">
        <a href="https://github.com/Ext-Creators/discord-ext-ipc/actions?query=workflow%3AAnalyze+event%3Apush">
            <img alt="Analyze Status"
                 src="https://github.com/Ext-Creators/discord-ext-ipc/workflows/Analyze/badge.svg?event=push" />
        </a>

        <a href="https://github.com/Ext-Creators/discord-ext-ipc/actions?query=workflow%3ABuild+event%3Apush">
            <img alt="Build Status"
                 src="https://github.com/Ext-Creators/discord-ext-ipc/workflows/Build/badge.svg?event=push" />
        </a>

        <a href="https://github.com/Ext-Creators/discord-ext-ipc/actions?query=workflow%3ADeploy+event%3Apush">
            <img alt="Deploy Status"
                 src="https://github.com/Ext-Creators/discord-ext-ipc/workflows/Deploy/badge.svg?event=push" />
        </a>

        <a href="https://github.com/Ext-Creators/discord-ext-ipc/actions?query=workflow%3ALint+event%3Apush">
            <img alt="Lint Status"
                 src="https://github.com/Ext-Creators/discord-ext-ipc/workflows/Lint/badge.svg?event=push" />
        </a>
    </p>

----------

.. raw:: html

    <h1 align="center">discord-ext-ipc</h1>
    <p align="center">A discord.py extension for inter-process communication.</p>
    <h6 align="center">Copyright 2020-present Ext-Creators</h6>


Installation
------------

**Python >=3.5.3 is required.**

.. code-block:: sh

    pip install --upgrade discord-ext-ipc


See Also
--------

- The `documentation <https://ext-creators.github.io/docs/ipc/>`_.
- The `usage examples <https://github.com/Ext-Creators/discord-ext-ipc/tree/master/examples>`_.
- The `Ext-Creators Discord <https://discord.gg/fwYfYZJGck>`_.
